Ash.Policy.Check.PrivateAction (ash v3.24.3)

Copy Markdown View Source

This check is true when the current action is private (public?: false).

Use it to bypass authorization for internal-only actions that must never be exposed by API extensions (e.g. AshGraphql, AshJsonApi):

policy bypass private_action?() do
  authorize_if always()
end

Summary

Functions

eager_evaluate?()

Callback implementation for Ash.Policy.Check.eager_evaluate?/0.

init(opts)

Callback implementation for Ash.Policy.Check.init/1.

prefer_expanded_description?()

Callback implementation for Ash.Policy.Check.prefer_expanded_description?/0.

requires_original_data?(_, _)

Callback implementation for Ash.Policy.Check.requires_original_data?/2.

strict_check(actor, context, opts)

Callback implementation for Ash.Policy.Check.strict_check/3.

type()

Callback implementation for Ash.Policy.Check.type/0.