left has 1
this predicate matches if the right value is in the list on the left
Summary
Functions
Callback implementation for Ash.Query.Operator.evaluate/1.
left has 1
this predicate matches if the right value is in the list on the left
Callback implementation for Ash.Query.Operator.evaluate/1.