Ash.Resource.Pipeline (ash v3.23.1)

Copy Markdown View Source

Represents a reusable pipeline of changes, validations, and preparations that can be referenced from multiple actions via pipe_through.

Summary

Types

t()

@type t() :: %Ash.Resource.Pipeline{
  __spark_metadata__: Spark.Dsl.Entity.spark_meta(),
  changes: list(),
  description: String.t() | nil,
  name: atom(),
  preparations: list(),
  validations: list()
}

Functions

schema()