Ash.Resource.Record (ash v3.27.8)

Copy Markdown View Source

In Ash, a record is an instance of a resource.

This module acts as a way to refer to the type via t:t() and will also act as a place for shared functionality for instances of resouces in the future.

Summary

Types

t()

@type t() :: struct()