Ash.Can (ash v3.26.0)

Copy Markdown View Source

Contains the Ash.can function logic.

Summary

Functions

Returns a an ok tuple if the actor can perform the action, query, or changeset, an error tuple if an error happens, and a ok tuple with maybe if maybe is set to true or not set.

Returns whether an actor can perform an action, query, or changeset.

Types

subject()

@type subject() ::
  Ash.Query.t()
  | Ash.Changeset.t()
  | Ash.ActionInput.t()
  | {Ash.Resource.t(), atom() | Ash.Resource.Actions.action()}
  | {Ash.Resource.t(), atom() | Ash.Resource.Actions.action(), input :: map()}
  | {Ash.Resource.Record.t(), atom() | Ash.Resource.Actions.action()}
  | {Ash.Resource.Record.t(), atom() | Ash.Resource.Actions.action(),
     input :: map()}

Functions

can(action_or_query_or_changeset, domain, actor_or_scope, opts \\ [])

@spec can(subject(), Ash.Domain.t(), Ash.actor() | Ash.Scope.t(), Keyword.t()) ::
  {:ok, boolean() | :maybe}
  | {:ok, boolean(), term()}
  | {:ok, boolean(), Ash.Changeset.t(), Ash.Query.t()}
  | {:error, Ash.Error.t()}

Returns a an ok tuple if the actor can perform the action, query, or changeset, an error tuple if an error happens, and a ok tuple with maybe if maybe is set to true or not set.

You should prefer to use Ash.can/3 over this module, directly.

Note: maybe_is is set to :maybe, if not set.

can?(action_or_query_or_changeset, domain, actor, opts \\ [])

@spec can?(subject(), Ash.Domain.t(), Ash.Resource.Record.t(), Keyword.t()) ::
  boolean() | no_return()

Returns whether an actor can perform an action, query, or changeset.

You should prefer to use Ash.can?/3 over this module, directly.

Can raise an exception if return_forbidden_error is truthy in opts or there's an error.