Used when atomics for the given action type are not not supported by the data layer, but one is used.
Summary
Functions
Create an Elixir.Ash.Error.Invalid.AtomicsNotSupported without raising it.
Functions
@spec exception(opts :: Keyword.t()) :: %Ash.Error.Invalid.AtomicsNotSupported{ __exception__: true, action_type: term(), bread_crumbs: term(), class: term(), path: term(), resource: term(), splode: term(), stacktrace: term(), vars: term() }
Create an Elixir.Ash.Error.Invalid.AtomicsNotSupported without raising it.
Keys
- :resource
- :action_type