Represents a reusable pipeline of changes, validations, and preparations that can be referenced from multiple actions via pipe_through.
pipe_through
@type t() :: %Ash.Resource.Pipeline{ __spark_metadata__: Spark.Dsl.Entity.spark_meta(), changes: list(), description: String.t() | nil, name: atom(), preparations: list(), validations: list() }