mix ash.setup (ash v3.21.1)

Copy Markdown View Source

Runs all setup tasks for any extension on any resource/domain in your application.

On failure, raises with an error message listing each failed task and its exception. Each failure is recorded as {task_name, exception} (e.g. {"compile", error} or {extension_name, error}).

Summary

Functions

Runs all setup tasks for any extension on any resource/domain in your application.

Functions

run(argv, opts \\ [])

@spec run(
  [String.t()],
  keyword()
) :: :ok

Runs all setup tasks for any extension on any resource/domain in your application.